@@ -157,7 +157,7 @@ class Extend_Object:
             return self.keys()
         return None
 
-    def emplace(self, other: Object):
+    def emplace(self, other: Object, retain=(Name.Parent,)):
         """Copy all items from other without making a new object.
 
         Particularly when working with pages, it may be desirable to remove all
@@ -165,6 +165,9 @@ class Extend_Object:
         of it, in a way that preserves all links and references to the original
         page. (Or similarly, for other Dictionary objects in a PDF.)
 
+        Any Dictionary keys in the iterable *retain* are preserved. By default,
+        /Parent is retained.
+
         When a page is assigned (``pdf.pages[0] = new_page``), only the
         application knows if references to the original the original page are
         still valid. For example, a PDF optimizer might restructure a page
@@ -181,11 +184,22 @@ class Extend_Object:
             >>> pdf.pages[0].emplace(pdf.pages[1])
             >>> pdf.pages[0].objgen
             (16, 0)  # Same object
+
+        .. versionchanged:: 2.11.1
+            Added the *retain* argument.
         """
         if not self.same_owner_as(other):
             raise TypeError("Objects must have the same owner for emplace()")
-        del_keys = set(self.keys()) - set(other.keys())
-        for k in other.keys():
+
+        # .keys() returns strings, so make all strings
+        retain = set(str(k) for k in retain)
+        self_keys = set(self.keys())
+        other_keys = set(other.keys())
+
+        assert all(isinstance(k, str) for k in (retain | self_keys | other_keys))
+
+        del_keys = self_keys - other_keys - retain
+        for k in (k for k in other_keys if k not in retain):
             self[k] = other[k]  # pylint: disable=unsupported-assignment-operation
         for k in del_keys:
             del self[k]  # pylint: disable=unsupported-delete-operation
@@ -275,6 +289,9 @@ class Extend_Pdf:
     def root(self):
         """
         Deprecated alias for .Root, the /Root object of the PDF.
+
+        .. deprecated:: 2.0
+            Use ``.Root``.
         """
         warn("Pdf.root is deprecated; use Pdf.Root", category=DeprecationWarning)
         return self.Root
@@ -317,6 +334,9 @@ class Extend_Pdf:
         You can delete the document information dictionary by deleting this property,
         ``del pdf.docinfo``. Note that accessing the property after deleting it
         will re-create with a new, empty dictionary.
+
+        .. versionchanged: 2.4
+            Added support for ``del pdf.docinfo``.
         """
         if Name.Info not in self.trailer:
             self.trailer.Info = self.make_indirect(Dictionary())
@@ -774,6 +794,9 @@ class Extend_Pdf:
             pikepdf can read PDFs with incremental updates, but always
             coalesces any incremental updates into a single non-incremental
             PDF file when saving.
+
+        .. versionchanged:: 2.7
+            Added *recompress_flate*.
         """
         if not filename_or_stream and self._original_filename:
             filename_or_stream = self._original_filename
@@ -1021,6 +1044,8 @@ class Extend_Page:
 
         Example:
             >>> resource_name = Page(pdf.pages[0]).add_resource(formxobj, Name.XObject)
+
+        .. versionadded: 2.3
         """
         if not Name.Resources in self.obj:
             self.obj.Resources = Dictionary()
