@@ -129,8 +129,7 @@ open_pdf(
         success = true;
     }
 
-    if (!success)
-        throw py::value_error("Failed to open the file");
+    // At this point, either we succeeded or threw an exception
 
     if (inherit_page_attributes) {
         // This could be expensive for a large file, plausibly (not tested),
@@ -786,8 +785,8 @@ void init_qpdf(py::module_ &m)
             py::arg("h")
         )
         .def("_replace_object",
-            [](QPDF &q, int objid, int gen, QPDFObjectHandle &h) {
-                q.replaceObject(objid, gen, h);
+            [](QPDF &q, std::pair<int, int> objgen, QPDFObjectHandle &h) {
+                q.replaceObject(objgen.first, objgen.second, h);
             }
         )
         .def("_swap_objects",
